@@ -5,7 +5,7 @@ from pathlib import Path
 
 import click
 
-from kks.ejudge import AuthData, ejudge_auth, check_session
+from kks.ejudge import AuthData
 
 
 def config_directory():
@@ -29,99 +29,6 @@ def write_config(config):
         config.write(f)
 
 
-def store_session(session):
-    cookies = config_directory() / 'cookies.pickle'
-    with open(cookies, 'wb') as f:
-        pickle.dump(session.cookies, f)
-
-
-def load_session():
-    import requests
-
-    cookies = config_directory() / 'cookies.pickle'
-    if not cookies.is_file():
-        return None
-
-    session = requests.session()
-    with open(cookies, 'rb') as f:
-        try:
-            cookies = pickle.load(f)
-        except Exception:
-            return None
-        session.cookies.update(cookies)
-    return session
-
-
-def save_auth_data(auth_data, store_password=True):
-    config = read_config()
-    config['Auth'] = {
-        'login': auth_data.login,
-        'contest': auth_data.contest_id
-    }
-
-    if store_password and auth_data.password is not None:
-        config['Auth']['password'] = auth_data.password
-
-    write_config(config)
-
-
-def load_auth_data():
-    config = read_config()
-    if not config.has_section('Auth'):
-        return None
-    auth = config['Auth']
-    if 'login' in auth and 'contest' in auth:
-        return AuthData(auth['login'], auth['contest'], auth.get('password', None))
-    return None
-
-
-def save_links(links):
-    config = read_config()
-    config['Links'] = links
-    write_config(config)
-
-
-def load_links():
-    config = read_config()
-    if config.has_section('Links'):
-        return config['Links']
-    return None
-
-
-def get_valid_session():
-    import requests
-
-    session = load_session()
-
-    if session is not None:
-        links = load_links()
-        if links is None or not check_session(links, session):
-            session = None
-
-    if session is None:
-        auth_data = load_auth_data()
-        if auth_data is None:
-            click.secho('No valid cookies or auth data, please use "kks auth" to log in', fg='yellow', err=True)
-            return None
-
-        click.secho('Cookies are either missing or invalid, trying to auth with saved data', fg='yellow', err=True)
-        store_password = True
-        if auth_data.password is None:
-            store_password = False
-            auth_data.password = click.prompt('Password', hide_input=True)
-
-        session = requests.session()
-        links = ejudge_auth(auth_data, session)
-        if links is None:
-            return None
-
-        save_auth_data(auth_data, store_password)
-        save_links(links)
-        store_session(session)
-
-    return session
-
-
 def get_clang_style_string():
     cfg = config_directory() / '.clang-format'
     if cfg.exists():
